==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/sdk/actions/mesh/meshprocessing/Decimation.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/


#ifndef DECIMATION_H
#define DECIMATION_H

#include <QObject>
#include <Action.h>

class DecimationWidget;

class Decimation : public camitk::Action {
    
public:
    /// the constructor
    Decimation(camitk::ActionExtension*);

    /// the destructor
    virtual ~Decimation();
    
    /// this method creates and returns the widget containing the user interface for the action
    virtual QWidget * getWidget();

public slots:
    /// method called when the action is applied
    virtual ApplyStatus apply();

private:
    /// action widget
    DecimationWidget *actionWidget;

};

#endif // DECIMATION_H

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/actions/mesh/meshprocessing/Decimation.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/


#ifndef DECIMATION_H
#define DECIMATION_H

#include <QObject>
#include <Action.h>

class DecimationWidget;

/**
 * @ingroup group_sdk_actions_mesh_meshprocessing
 * 
 * @brief
 * Decimate the input mesh in order to reduce its number of triangles.
 *
 * @see camitk::DecimationWidget 
 *
 */
class Decimation : public camitk::Action {
    
public:
    /// the constructor
    Decimation(camitk::ActionExtension*);

    /// the destructor
    virtual ~Decimation();
    
    /// this method creates and returns the widget containing the user interface for the action
    virtual QWidget * getWidget();

public slots:
    /// method called when the action is applied
    virtual ApplyStatus apply();

private:
    /// action widget
    DecimationWidget *actionWidget;

};

#endif // DECIMATION_H
